<?php

namespace KnitPay\Extensions\MicroJobEngine;

/**
 * Title: Micro Job Engine Gateway
 * Description:
 * Copyright: 2020-2021 Knit Pay
 * Company: Knit Pay
 *
 * @author  knitpay
 * @since   4.7.0
 */

/**
 * Prevent loading this file directly
 */
defined( 'ABSPATH' ) || exit();

class Gateway {

		/**
		 * @var string
		 */
		public $id = 'knit_pay';

	/**
	 * Bootstrap
	 */
	public function __construct() {
		$this->setting = ae_get_option( $this->id );

		add_action( 'mje_after_payment_list', array( $this, 'mje_render_button' ) );

		add_filter( 'mje_render_payment_name', array( $this, 'render_payment_name' ) );
	}

	/**
	 * Filter payment name
	 *
	 * @param array $payment_name
	 * @return array $payment_name
	 */
	function render_payment_name( $payment_name ) {
		$key = $this->id;

		$name      = $this->get_title();
		$icon_path = $this->get_icon_path();

		$payment_name[ $key ] = "<p class='payment-name {$key}' title='{$name}'><img src='{$icon_path}'/><span>{$name}</span></p>";

		return $payment_name;
	}

	private function get_icon_path() {
		$icon_url = $this->setting['icon_url'];
		if ( empty( $icon_url ) ) {
			$icon_url = 'https://plugins.svn.wordpress.org/knit-pay/assets/icon.svg';
		}
		return $icon_url;
	}

	private function get_title() {
		$name = $this->setting['title'];
		if ( empty( $name ) ) {
			$name = __( 'Knit Pay', 'knit-pay-lang' );
		}
		return $name;
	}

	public function mje_render_button() {
		if ( isset( $this->setting['enable'] ) && $this->setting['enable'] ) :
			?>
			<li>
				<div class="outer-payment-items hvr-underline-from-left">
					<a href="#" class="btn-submit-price-plan select-payment" data-type="<?php echo $this->id; ?>">
						<img src="<?php echo $this->get_icon_path(); ?>" alt="" style="height: 75px;">
						<p><?php echo $this->get_title(); ?></p>
					</a>
				</div>
			</li>
			<?php
		endif;
	}
}
